summaryrefslogtreecommitdiffstats
path: root/lib/plugin.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/plugin.h')
-rw-r--r--lib/plugin.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/lib/plugin.h b/lib/plugin.h
index 59322ac..b4eb59f 100644
--- a/lib/plugin.h
+++ b/lib/plugin.h
@@ -82,9 +82,9 @@ Q_OBJECT
public:
/**
* Constructor. Creates a conduit configuration support object
* with the given tqparent @p tqparent and name (optional) @p n.
*/
- ConduitConfigBase(TQWidget *tqparent=0L, const char *n=0L);
+ ConduitConfigBase(TQWidget *parent=0L, const char *n=0L);
/** Destructor. */
virtual ~ConduitConfigBase();
@@ -152,10 +152,10 @@ public:
* application's icon. This widget can be used pretty much
* anywhere. Copied from KAboutDialog, mostly.
*
* @param tqparent The widget that holds the about widget.
* @param data The KAboutData that is used to populate the widget.
*/
- static TQWidget *aboutPage(TQWidget *tqparent, KAboutData *data=0L);
+ static TQWidget *aboutPage(TQWidget *parent, KAboutData *data=0L);
protected:
/**
@@ -444,7 +444,7 @@ namespace PluginUtility
*
* <pre>
* protected:
-* virtual TQObject* createObject( TQObject* tqparent = 0,
+* virtual TQObject* createObject( TQObject* parent = 0,
* const char* name = 0,
* const char* classname = TQOBJECT_OBJECT_NAME_STRING,
* const TQStringList &args = TQStringList() );
@@ -82,9 +82,9 @@ Q_OBJECT
/**
* Constructor. Creates a conduit configuration support object
- * with the given tqparent @p tqparent and name (optional) @p n.
+ * with the given parent @p parent and name (optional) @p n.
*/
@@ -152,10 +152,10 @@ public:
* anywhere. Copied from KAboutDialog, mostly.
*
- * @param tqparent The widget that holds the about widget.
+ * @param parent The widget that holds the about widget.
* @param data The KAboutData that is used to populate the widget.
*/